@@ -446,4 +446,17 @@ cross <- function(a, b) {
   vec_out[3] <- a[1] * b[2] - a[2] * b[1]
   vec_out <- vec_out / (sum(vec_out ^ 2) ^ 0.5)
   vec_out
+}
+
+#' Create a logical circular mask spanning the full extent of an n x n matrix.
+#' @param d diameter of the mask.
+#' @param n number of matrix rows and columns.
+#' @param offset offset the mask centre in matrix dimension units.
+#' @return logical n x n mask matrix.
+#' @export
+circ_mask <- function(d, n, offset = 1) {
+  g <- expand.grid(1:n, 1:n)
+  dist <- sqrt((g$Var1 - n / 2 - offset) ^ 2 + (g$Var2 - n / 2 - offset) ^ 2)
+  dist <- matrix(dist, n, n)
+  return(dist <= d / 2)
 }
\ No newline at end of file
